@@ -5,19 +5,19 @@
 # saving the last plot that you displayed, and for a default size uses 
 # the size of the current graphics device.  It also guess the type of 
 # graphics device from the extension.  This means the only argument you 
-# need to supply is the path.
+# need to supply is the filename.
 # 
 # \code{ggsave} currently recognises the extensions ps, tex (pictex), pdf,
 # tiff, png, bmp and wmf (windows only).
 # 
 # @arguments plot to save, defaults to last plot displayed
-# @arguments file name/path of plot
+# @arguments file name/filename of plot
 # @arguments device to use, automatically extract from file name extension
+# @arguments path to save plot to (if you just want to set path and not filename)
 # @arguments scaling factor
 # @arguments width (in inches)
 # @arguments height (in inches)
 # @arguments dpi to use for raster graphics
-# @arguments path where file should be saved (if filename unspecified)
 # @arguments other arguments passed to graphics device
 # @keyword file 
 #X \dontrun{
@@ -30,20 +30,32 @@
 #X # make twice as big as on screen
 #X ggsave(ratings, file="ratings.pdf", scale=2)
 #X }
-ggsave <- function(plot = last_plot(), filename=default_name(plot), device=default_device(filename), scale=1, width=par("din")[1], height=par("din")[2], dpi=72, path="", keep = plot$options$keep, drop = plot$options$drop, ...) {
+ggsave <- function(plot = last_plot(), filename=default_name(plot), device=default_device(filename), path = "", scale=1, width=par("din")[1], height=par("din")[2], dpi=300, keep = plot$options$keep, drop = plot$options$drop, ...) {
+  if (!inherits(plot, "ggplot")) stop("plot should be a ggplot2 plot")
 
-  ps <- function(..., width, height)  grDevices::postscript(..., width=width, height=height)
-  tex <- function(..., width, height) grDevices::pictex(..., width=width, height=height)
-  pdf <- function(..., version="1.4") grDevices::pdf(..., version=version)
-  wmf <- function(..., width, height) grDevices::win.metafile(..., width=width, height=height)
+  eps <- ps <- function(..., width, height)  
+    grDevices::postscript(..., width=width, height=height, onefile=FALSE,
+      horizontal = FALSE, paper = "special")
+  tex <- function(..., width, height) 
+    grDevices::pictex(..., width=width, height=height)
+  pdf <- function(..., version="1.4") 
+    grDevices::pdf(..., version=version)
+  svg <- function(...) 
+    grDevices::svg(...)
+  wmf <- function(..., width, height) 
+    grDevices::win.metafile(..., width=width, height=height)
 
-  png <- function(..., width, height) grDevices::png(..., width=width*dpi, height=height*dpi, res = dpi)
-  jpeg <- function(..., width, height) grDevices::jpeg(..., width=width*dpi, height=height*dpi, res = dpi)
-  bmp <- function(..., width, height) grDevices::bmp(..., width=width*dpi, height=height*dpi, res = dpi)
-  tiff <- function(..., width, height) grDevices::tiff(..., width=width*dpi, height=height*dpi, res = dpi)
+  png <- function(..., width, height) 
+    grDevices::png(...,  width=width, height=height, res = dpi, units = "in")
+  jpeg <- function(..., width, height) 
+    grDevices::jpeg(..., width=width, height=height, res = dpi, units = "in")
+  bmp <- function(..., width, height) 
+    grDevices::bmp(...,  width=width, height=height, res = dpi, units = "in")
+  tiff <- function(..., width, height) 
+    grDevices::tiff(..., width=width, height=height, res = dpi, units = "in")
   
   default_name <- function(plot) { 
-    paste(path, digest.ggplot(plot), ".png", sep="")
+    paste(path, digest.ggplot(plot), ".pdf", sep="")
   }
   
   default_device <- function(filename) {
