@@ -7,7 +7,7 @@ ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {
   
   tr_default <- "identity"
 
-  new <- function(., name=NULL, limits=NULL, breaks=NULL, labels=NULL, variable, trans = NULL, expand=c(0.05, 0), minor_breaks = NULL, ...) {
+  new <- function(., name=NULL, limits=NULL, breaks=NULL, labels=NULL, variable, trans = NULL, expand=c(0.05, 0), minor_breaks = NULL, formatter = "scientific", ...) {
     if (is.null(breaks) && !is.null(labels)) stop("Labels can only be specified in conjunction with breaks")
     
     if (is.null(trans))      trans <- .$tr_default
@@ -16,8 +16,13 @@ ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {
     # Transform limits and breaks
     limits <- trans$transform(limits)
     breaks <- trans$transform(breaks)
+    minor_breaks <- trans$transform(minor_breaks)
     
-    .$proto(name=name, .input=variable, .output=variable, limits=limits, breaks = breaks, .labels = labels, .expand=expand, .tr = trans, minor_breaks = minor_breaks, ...)
+    .$proto(name=name, .input=variable, .output=variable, limits=limits, breaks = breaks, .labels = labels, .expand=expand, .tr = trans, minor_breaks = minor_breaks, formatter = formatter, ...)
+  }
+  
+  set_limits <- function(., limits) {
+    .$limits <- .$.tr$transform(limits)
   }
 
   
@@ -27,7 +32,7 @@ ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {
     output <- .$output()
     
     if (length(input) == 1 && input %in% c("x", "y")) {
-      matches <- grep(paste("^", input, sep =""), names(df))
+      matches <- aes_to_scale(names(df)) == input
       input <- output <- names(df)[matches]
     }
     input <- intersect(input, names(df))
@@ -79,7 +84,9 @@ ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {
 
     l <- .$.tr$label(b)
     numeric <- sapply(l, is.numeric)
-    l[numeric] <- format(unlist(l[numeric]), trim = TRUE)
+    
+    f <- match.fun(get("formatter", .))
+    l[numeric] <- f(unlist(l[numeric]))
     l
   }
   
@@ -95,7 +102,7 @@ ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {
   }
   
   objname <- "continuous"
-  common <- c("x", "y", "z")
+  common <- c("x", "y")
   desc <- "Continuous position scale"
   seealso <- list(
     "scale_discrete" = "Discrete position scales"
@@ -113,6 +120,11 @@ ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {
     m + scale_y_continuous(limits=c(0, 5000))
     m + scale_y_continuous(limits=c(1000, 10000))
     m + scale_x_continuous(limits=c(7, 8))
+    
+    # you can also use the short hand functions xlim and ylim
+    m + ylim(0, 5000)
+    m + ylim(1000, 10000)
+    m + xlim(7, 8)
 
     #  * choose where the ticks appear
     m + scale_x_continuous(breaks=1:10)
@@ -131,6 +143,15 @@ ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {
     m + scale_y_reverse()
     # see ?transformer for a full list
     
+    # You can control the formatting of the labels with the formatter
+    # argument.  Some common formats are built in:
+    x <- rnorm(10) * 100000
+    y <- seq(0, 1, length = 10)
+    p <- qplot(x, y)
+    p + scale_y_continuous(formatter = "percent")
+    p + scale_y_continuous(formatter = "dollar")
+    p + scale_x_continuous(formatter = "comma")
+    
     # qplot allows you to do some of this with a little less typing:
     #   * axis limits
     qplot(rating, votes, data=movies, ylim=c(1e4, 5e4))
@@ -141,43 +162,3 @@ ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {
   }
 })
 
-# Set x limits
-# Convenience function to set the limits of the x axis.
-# 
-# Works by creating a new continuous scale, so will only work for 
-# continuous variables.
-# 
-# @arguments lower limit
-# @arguments upper limit
-# @keyword hplot
-#X qplot(mpg, wt, data=mtcars) + xlim(15, 20)
-xlim <- function(min=NA, max=NA) {
-  scale_x_continuous(limits = c(min, max))
-}
-
-# Set y limits
-# Convenience function to set the limits of the y axis.
-# 
-# Works by creating a new continuous scale, so will only work for 
-# continuous variables.
-# 
-# @arguments lower limit
-# @arguments upper limit
-# @keyword hplot
-#X qplot(mpg, wt, data=mtcars) + ylim(15, 20)
-ylim <- function(min=NA, max=NA) {
-  scale_y_continuous(limits = c(min, max))
-}
-
-# Set z limits
-# Convenience function to set the limits of the z axis.
-# 
-# Works by creating a new continuous scale, so will only work for 
-# continuous variables.
-# 
-# @arguments lower limit
-# @arguments upper limit
-# @keyword hplot
-zlim <- function(min=NA, max=NA) {
-  scale_z_continuous(limits = c(min, max))
-}
