@@ -3,10 +3,10 @@ ScaleLinetype <- proto(ScaleDiscrete, expr={
   common <- NULL
   .input <- .output <- "linetype"
 
-  output_set <- function(.) c("22", "44", "13", "1343", "73", "2262", "12223242", "F282", "F4448444", "224282F2", "F1")[seq_along(.$input_set())]
-  max_levels <- function(.) 4
+  output_set <- function(.) c("solid", "22", "42", "44", "13", "1343", "73", "2262", "12223242", "F282", "F4448444", "224282F2", "F1")[seq_along(.$input_set())]
+  max_levels <- function(.) 12
   
-  detail <- "<p>Default line types supplied by Richard Pearson, University of Manchester.</p>"
+  detail <- "<p>Default line types based on a set supplied by Richard Pearson, University of Manchester.</p>"
   
   # Documentation -----------------------------------------------
 
