@@ -36,7 +36,7 @@
 ggpcp <- function(data, vars=names(data), scale="range", ...) {
   force(vars)  
   scaled <- rescaler(data[, vars], type=scale)
-  data <- cbind(scaled, data[, setdiff(names(data), vars), drop=FALSE])
+  data <- cunion(scaled, data)
   
   data$ROWID <- 1:nrow(data)
   molten <- melt(data, m=vars)
@@ -190,7 +190,7 @@ ggdist <- function(data, vars=names(data), facets = . ~ .) {
       geom_bar()
 
     pushViewport(viewport(layout.pos.col=i))
-    grid.draw(ggplotGrob(p, pretty=FALSE))
+    grid.draw(ggplotGrob(p))
     popViewport()
   }, names(data[vars]), cat, 1:ncol(data[vars]))
   invisible()
