@@ -3,6 +3,7 @@
 # 
 # @argument base font size
 # @keywords dplot
+# @alias theme_grey
 theme_gray <- function(base_size = 12) {
   structure(list(
     axis.line =         theme_blank(),
@@ -15,18 +16,18 @@ theme_gray <- function(base_size = 12) {
     axis.ticks.margin = unit(0.1, "cm"),
 
     legend.background = theme_rect(colour=NA), 
-    legend.key =        theme_rect(fill = "grey95", colour = "grey80"),
+    legend.key =        theme_rect(fill = "grey95", colour = "white"),
     legend.text =       theme_text(size = base_size),
     legend.title =      theme_text(size = base_size, face = "bold", hjust = 0),
     legend.position =   "right",
 
     panel.background =  theme_rect(fill = "grey90", colour = NA), 
-    panel.border =      theme_rect(fill = NA, colour="white", size=2), 
+    panel.border =      theme_blank(), 
     panel.grid.major =  theme_line(colour = "white"),
     panel.grid.minor =  theme_line(colour = "grey95", size = 0.25),
-    panel.empty =       theme_rect(fill = "white", colour = NA),
+    panel.margin =      unit(0.25, "lines"),
 
-    strip.background =  theme_rect(fill = "grey80"), 
+    strip.background =  theme_rect(fill = "grey80", colour = NA), 
     strip.label =       function(variable, value) value, 
     strip.text.x =      theme_text(size = base_size * 0.8),
     strip.text.y =      theme_text(size = base_size * 0.8, angle = -90),
@@ -35,6 +36,7 @@ theme_gray <- function(base_size = 12) {
     plot.title =        theme_text(size = base_size * 1.2)
   ), class = "options")
 }
+theme_grey <- theme_gray
 
 # Black and white theme
 # Produce a theme with white background and black gridlines
@@ -46,7 +48,7 @@ theme_bw <- function(base_size = 12) {
     axis.line =         theme_blank(),
     axis.text.x =       theme_text(size = base_size * 0.8 , lineheight = 0.9, vjust = 1),
     axis.text.y =       theme_text(size = base_size * 0.8, lineheight = 0.9, hjust = 1),
-    axis.ticks =        theme_segment(colour = "grey80", size = 1.5),
+    axis.ticks =        theme_segment(colour = "black", size = 0.2),
     axis.title.x =      theme_text(size = base_size),
     axis.title.y =      theme_text(size = base_size, angle = 90),
     axis.ticks.length = unit(0.3, "lines"),
@@ -59,12 +61,12 @@ theme_bw <- function(base_size = 12) {
     legend.position =   "right",
 
     panel.background =  theme_rect(fill = "white", colour = NA), 
-    panel.border =      theme_rect(fill = NA, colour="black", size=1.5), 
-    panel.grid.major =  theme_line(colour = "grey80"),
-    panel.grid.minor =  theme_line(colour = "grey95", size = 0.2),
-    panel.empty =       theme_rect(fill = "white", colour = NA),
+    panel.border =      theme_rect(fill = NA, colour="grey50"), 
+    panel.grid.major =  theme_line(colour = "grey90", size = 0.2),
+    panel.grid.minor =  theme_line(colour = "grey98", size = 0.5),
+    panel.margin =      unit(0.25, "lines"),
 
-    strip.background =  theme_rect(fill = "grey80", colour = "black"), 
+    strip.background =  theme_rect(fill = "grey80", colour = "grey50"), 
     strip.label =       function(variable, value) value, 
     strip.text.x =      theme_text(size = base_size * 0.8),
     strip.text.y =      theme_text(size = base_size * 0.8, angle = -90),
