@@ -5,9 +5,11 @@ coord_map <- CoordMap$build_accessor()
 coord_polar <- CoordPolar$build_accessor()
 coord_trans <- CoordTrans$build_accessor()
 facet_grid <- FacetGrid$build_accessor()
+facet_wrap <- FacetWrap$build_accessor()
 geom_abline <- GeomAbline$build_accessor()
 geom_area <- GeomArea$build_accessor()
 geom_bar <- GeomBar$build_accessor()
+geom_bin2d <- GeomBin2d$build_accessor()
 geom_blank <- GeomBlank$build_accessor()
 geom_boxplot <- GeomBoxplot$build_accessor()
 geom_contour <- GeomContour$build_accessor()
@@ -15,6 +17,8 @@ geom_crossbar <- GeomCrossbar$build_accessor()
 geom_density <- GeomDensity$build_accessor()
 geom_density2d <- GeomDensity2d$build_accessor()
 geom_errorbar <- GeomErrorbar$build_accessor()
+geom_freqpoly <- GeomFreqpoly$build_accessor()
+geom_hex <- GeomHex$build_accessor()
 geom_histogram <- GeomHistogram$build_accessor()
 geom_hline <- GeomHline$build_accessor()
 geom_jitter <- GeomJitter$build_accessor()
@@ -102,28 +106,16 @@ scale_y_prob <- ScaleProb$build_accessor(list(variable = "\"y\""))
 scale_y_probit <- ScaleProbit$build_accessor(list(variable = "\"y\""))
 scale_y_reverse <- ScaleReverse$build_accessor(list(variable = "\"y\""))
 scale_y_sqrt <- ScaleSqrt$build_accessor(list(variable = "\"y\""))
-scale_z_asn <- ScaleAsn$build_accessor(list(variable = "\"z\""))
-scale_z_atanh <- ScaleAtanh$build_accessor(list(variable = "\"z\""))
-scale_z_continuous <- ScaleContinuous$build_accessor(list(variable = "\"z\""))
 scale_z_discrete <- ScaleDiscretePosition$build_accessor(list(variable = "\"z\""))
-scale_z_exp <- ScaleExp$build_accessor(list(variable = "\"z\""))
-scale_z_inverse <- ScaleInverse$build_accessor(list(variable = "\"z\""))
-scale_z_log <- ScaleLog$build_accessor(list(variable = "\"z\""))
-scale_z_log10 <- ScaleLog10$build_accessor(list(variable = "\"z\""))
-scale_z_log2 <- ScaleLog2$build_accessor(list(variable = "\"z\""))
-scale_z_logit <- ScaleLogit$build_accessor(list(variable = "\"z\""))
-scale_z_pow <- ScalePow$build_accessor(list(variable = "\"z\""))
-scale_z_pow10 <- ScalePow10$build_accessor(list(variable = "\"z\""))
-scale_z_prob <- ScaleProb$build_accessor(list(variable = "\"z\""))
-scale_z_probit <- ScaleProbit$build_accessor(list(variable = "\"z\""))
-scale_z_reverse <- ScaleReverse$build_accessor(list(variable = "\"z\""))
-scale_z_sqrt <- ScaleSqrt$build_accessor(list(variable = "\"z\""))
 stat_bin <- StatBin$build_accessor()
+stat_bin2d <- StatBin2d$build_accessor()
+stat_binhex <- StatBinhex$build_accessor()
 stat_boxplot <- StatBoxplot$build_accessor()
 stat_contour <- StatContour$build_accessor()
 stat_density <- StatDensity$build_accessor()
 stat_density2d <- StatDensity2d$build_accessor()
 stat_function <- StatFunction$build_accessor()
+stat_hline <- StatHline$build_accessor()
 stat_identity <- StatIdentity$build_accessor()
 stat_qq <- StatQq$build_accessor()
 stat_quantile <- StatQuantile$build_accessor()
@@ -132,3 +124,4 @@ stat_spoke <- StatSpoke$build_accessor()
 stat_sum <- StatSum$build_accessor()
 stat_summary <- StatSummary$build_accessor()
 stat_unique <- StatUnique$build_accessor()
+stat_vline <- StatVline$build_accessor()
